//
//  KBGCardGenerator.h
//  Keynote Bingo Generator
//
//  Created by Peter Hosey on 2007-01-01.
//  Copyright 2007 Peter Hosey. All rights reserved.
//

/*This is where the meat is!
 *The singleton instance of this class is responsible for the actual generation of bingo cards.
 */

@interface KBGCardGenerator : NSObject {
	IBOutlet NSWindow *window;
	IBOutlet NSButton *pageSetupButton;

	NSMutableSet *tempFiles;

	//We use Carbon Printing Manager because Cocoa printing does not support the third orientation button (flipped landscape). Carbon Printing Manager does.
	//This wouldn't be a problem if we were actually using Cocoa printing, but since we're generating the PDF ourselves using CGPSConverter, we need to do our own work, and that includes handling orientation ourselves.
	//Since we can't find out that the user selected the third button using Cocoa, we must use Carbon, in order to correctly carry out the user's wishes.
	PMPrintSession printSession;
	PMPageFormat   pageFormat;

	unsigned numberOfCardsPerPage; //Expected to be 1, 2, or 4.
	unsigned seedNumber;
	BOOL useSeedNumber; //If NO, we won't emit a seed, and the bingo card file will use usertime.
	BOOL incrementSeedNumber; //Used for >1-up. If YES, the user-provided seed number will be incremented for each card. If NO, the seed number will evolve normally.
}

+ (KBGCardGenerator *)sharedGenerator;

- (IBAction)useSeedOrNotChanged:sender; //Called by the “New random card”/“Card with seed” radio button matrix.
- (IBAction)furtherSeedsMethodChanged:sender; //Called by the “Increment”/“Random” radio button matrix.
- (IBAction)nupChanged:sender; //Called by the 1-up/2-up/4-up radio button matrix.

- (IBAction)runPageLayout:sender;
- (IBAction)bingoMePlease:sender;

@end
