//
//  KBGPDFDocument.m
//  Keynote Bingo Generator
//
//  Created by Peter Hosey on 2007-01-01.
//  Copyright 2007 Peter Hosey. All rights reserved.
//

#import "KBGPDFDocument.h"

@implementation KBGPDFDocument

#pragma mark Document types

/*Without these two methods, we get this message:
 *	Trying to save a document without any appropriate writable type defined.
 */
+ (BOOL)isNativeType:(NSString *)type {
	return [type isEqualToString:@"PDF document"];
}
+ (NSArray *)writableTypes {
	return [NSArray arrayWithObjects:
		@"PDF document",
		nil];
}

#pragma mark Birth and death

- (void)dealloc {
	[document release];
	[super dealloc];
}

#pragma mark The nib

- (NSString *)windowNibName {
	return @"KBGPDFDocument";
}

- (void)windowControllerDidLoadNib:(NSWindowController *)windowController {
	[view setDocument:document];
	[view setDisplayBox:kPDFDisplayBoxTrimBox];

	NSWindow *window = [view window];
	PDFPage *page = [document pageAtIndex:0U];

	NSRect pageBounds = [page boundsForBox:kPDFDisplayBoxTrimBox];
	//EVIL HAX! PDFView adds a matte view around the document and won't let me turn it off nor access its size. Therefore I must assume its size.
	pageBounds.size.width  += 14.0f;
	pageBounds.size.height += 14.0f;
	NSRect contentRect = { [window contentRectForFrameRect:[window frame]].origin, pageBounds.size };
	[window setFrame:[window frameRectForContentRect:contentRect] display:YES animate:YES];

	[super windowControllerDidLoadNib:windowController];
}

#pragma mark File I/O

- (BOOL)readFromData:(NSData *)data ofType:(NSString *)type error:(out NSError **)outError {
	document = [[PDFDocument alloc] initWithData:data];
	return (document != nil);
}
- (NSData *)dataOfType:(NSString *)type error:(out NSError **)outError {
	return nil;
}

- (BOOL)readFromURL:(NSURL *)absoluteURL ofType:(NSString *)typeName error:(NSError **)outError {
	document = [[PDFDocument alloc] initWithURL:absoluteURL];
	return (document != nil);
}
- (BOOL)writeToURL:(NSURL *)absoluteURL ofType:(NSString *)typeName error:(NSError **)outError {
	return [document writeToURL:absoluteURL];
}

@end
